
;;;----------------------------------------------------------------------
;;; Example 1c
;;; plate - bow - bowed
;;;----------------------------------------------------------------------

(new)
(multi)
(set-sample-rate 44100)

(defun midi2hz (x) (* 440 (expt 2 (/ (- x 69) 12))))

(load-component "connection")

;;;----------------------------------------------------------------------
;;; objects
;;;----------------------------------------------------------------------

(defvar my-plate)
(setq my-plate 
               (make-object 'rect-plate
               (thickness 0.2)
               (modes 160)
               (density 8500)
               (young 1.04e11)
               (freq-loss 0.4)
               (const-loss 0.3)))

(set-pitch my-plate 'size (midi2hz 36)) 

(defvar my-bow)
(setq my-bow (make-object 'bi-two-mass 
                          (small-mass .05)
                          (large-mass .05)
                          (stiffness0 50000)
                          (stiffness1 50000)
                          (freq-loss0 100)
                          (freq-loss1 100)
                          (const-loss0 0)
                          (const-loss1 0)))

;;;----------------------------------------------------------------------
;;;access 
;;;----------------------------------------------------------------------

(defvar my-bow-hor)
(setq my-bow-hor (make-access my-bow 1 'trans0))

(defvar my-bow-vert)
(setq my-bow-vert (make-access my-bow 1 'trans1))

(defvar my-plate-hor)
(setq my-plate-hor (make-access my-plate (const 0.1 0.1) 'normal))

(defvar my-plate-vert)
(setq my-plate-vert (make-access my-plate (const 0.1 0.1) 'normal))

(defvar my-plate-out1)
(setq my-plate-out1 (make-access my-plate (const 0.2 0.2) 'normal))
(defvar my-plate-out2)
(setq my-plate-out2 (make-access my-plate (const 0.8 0.8) 'normal))

;;;----------------------------------------------------------------------
;;;connections
;;;----------------------------------------------------------------------

(defvar my-bow-connection)
(setq my-bow-connection (make-connection 'bow
                          my-bow-vert my-bow-hor .01
                          my-plate-vert my-plate-hor 0
                          '(2 10 5 4)))

(defvar my-bow-hor-mov)
(setq my-bow-hor-mov (make-access my-bow (const 0) 'trans0))

(defvar my-bow-vert-mov)
(setq my-bow-vert-mov (make-access my-bow (const 0) 'trans1))

;;;----------------------------------------------------------------------
;;; controllers
;;;----------------------------------------------------------------------

(make-connection 'speed my-bow-hor-mov
                 (make-controller 'envelope 1
                                  (list (list 0.00  1)
                                        (list 0.10  4)
                                        (list 9.99  1))))

(make-connection 'position my-bow-vert-mov
                 (make-controller 'envelope 1
                                  (list (list 0.0  0.010)
                                        (list 0.2 -0.0001)
                                        (list 0.4 -0.002)
                                        (list 6.2 -0.003)
                                        (list 7.3  0.010)
                                        (list 9.9  0.010))))

;;;----------------------------------------------------------------------
;;; listening points on plate
;;;----------------------------------------------------------------------

(make-point-output my-plate-out1 0 (const 1))
(make-point-output my-plate-out2 1 (const 1))

;;;----------------------------------------------------------------------
;;; print useful information 
;;; (this function is defined in the "connection component")
;;;----------------------------------------------------------------------

(help-bow my-bow-connection)

;;;----------------------------------------------------------------------
;;; run the synthesis and play the sound
;;;----------------------------------------------------------------------

(run 10)
(play)