
;;;----------------------------------------------------------------------
;;; Example 3e
;;; string - bow - fingerboard - bowed
;;;----------------------------------------------------------------------

(new)
(multi)

(load-component "connection")

;;;----------------------------------------------------------------------
;;; objects
;;;----------------------------------------------------------------------

(defvar my-string)
(setq my-string (make-object 'bi-string 
                             (modes 40)
                             (length .5)
                             (tension 150)
                             (density 1000)
                             (radius .001)
                             (young .001)
                             (freq-loss 1)
                             (const-loss 1)))

(defvar my-bow)
(setq my-bow (make-object 'bi-two-mass 
                          (small-mass .05)
                          (large-mass .05)
                          (stiffness0 50000)
                          (stiffness1 50000)
                          (freq-loss0 100)
                          (freq-loss1 100)
                          (const-loss0 0)
                          (const-loss1 0)))

(defvar my-finger)
(setq my-finger (make-object 'bi-two-mass 
                          (small-mass .05)
                          (large-mass .05)
                          (stiffness0 50000)
                          (stiffness1 50000)
                          (freq-loss0 100)
                          (freq-loss1 100)
                          (const-loss0 0)
                          (const-loss1 0)))

;;;----------------------------------------------------------------------
;;; connections
;;;----------------------------------------------------------------------

;;; bow-connection ------------------------------------------------------

(defvar my-bow-hor)
(setq my-bow-hor (make-access my-bow 1 'trans0))

(defvar my-bow-vert)
(setq my-bow-vert (make-access my-bow 1 'trans1))

(defvar my-string-hor)
(setq my-string-hor (make-access my-string .1 'trans0))

(defvar my-string-vert)
(setq my-string-vert (make-access my-string .1 'trans1))

(defvar my-bow-connection)
(setq my-bow-connection (make-connection 'bow
                          my-bow-vert my-bow-hor .01
                          my-string-vert my-string-hor 0
                          '(2 10 5 4)))

(defvar my-bow-hor-mov)
(setq my-bow-hor-mov (make-access my-bow (const 0) 'trans0))

(defvar my-bow-vert-mov)
(setq my-bow-vert-mov (make-access my-bow (const 0) 'trans1))

;;; fingerboard-connection ----------------------------------------------

(defvar my-finger-top)
(setq my-finger-top (make-access my-finger (const 0) 'trans1))
(defvar my-finger-tip)
(setq my-finger-tip (make-access my-finger (const 1) 'trans1))

(defvar my-finger-hor-ctrl)
(setq my-finger-hor-ctrl(make-controller 'dynamic 1 0.001 (list 0.9)))
(defvar my-string-finger)
(setq my-string-finger (make-access my-string my-finger-hor-ctrl 'trans0))

(defvar my-finger-vert-ctrl)
(setq my-finger-vert-ctrl (make-controller 'dynamic 1 0.001 (list 0.02)))
(make-connection 'position my-finger-tip my-finger-vert-ctrl)

(make-connection 'mono-fingerboard my-finger-tip 0.02 my-string-finger 0.01 (const 0))

;;;----------------------------------------------------------------------
;;; controllers
;;;----------------------------------------------------------------------

;;; controlling the bow -------------------------------------------------

(make-connection 'speed my-bow-hor-mov
                 (make-controller 'envelope 1
                                  (list (list 0.00  1)
                                        (list 0.10  4)
                                        (list 9.99  1))))

(make-connection 'position my-bow-vert-mov
                 (make-controller 'envelope 1
                                  (list (list 0.0  0.010)
                                        (list 0.2 -0.001)
                                        (list 0.4 -0.001)
                                        (list 0.5  0.010)
                                        (list 0.6  0.010)
                                        (list 0.7 -0.001)
                                        (list 1.2 -0.001)
                                        (list 1.3  0.010)
                                        (list 9.9  0.010))))

;;;----------------------------------------------------------------------
;;; listening point on string
;;;----------------------------------------------------------------------

(make-point-output (make-access my-string (const .6) 'trans0))

;;;----------------------------------------------------------------------
;;; print useful information 
;;; (this function is defined in the "connection component")
;;;----------------------------------------------------------------------

;(help-bow my-bow-connection)

;;;----------------------------------------------------------------------
;;; run the synthesis and play the sound
;;;----------------------------------------------------------------------

(set-breakpoint my-finger-vert-ctrl (list 0.01 -0.001))
(run 1)
(set-breakpoint my-finger-hor-ctrl (list 1 0.3))
(run 2)
(set-breakpoint my-finger-hor-ctrl (list 1 0.5))
(run 4)
(set-breakpoint my-finger-vert-ctrl (list 2 0.1))
(run 3)

(play)