
;;;----------------------------------------------------------------------
;;; 05 extra
;;; Gong-3D-Model
;;;----------------------------------------------------------------------


(new)
(multi)
(set-sample-rate 44100)


;;;----------------------------------------------------------------------
;;; 3D mesh
;;;----------------------------------------------------------------------

(defvar scale)
(setq scale 0.5)

(defvar part1)
(setq part1 (make-mesh 'single-point (vector 0 0 (* scale 3))))
(duplicate 'rotation part1 9 (vector -1 0 0) (vector 0 0 0) 10)

(defvar part2)
(setq part2 (make-mesh 'single-point (vector 0 (* scale 3) 0)))
(duplicate 'translation part2 10 (vector 0 (* scale 1) 0))

(defvar part3)
(setq part3 (make-mesh 'single-point (vector 0 (* scale 13) 0)))
(duplicate 'translation part3 5 (vector 0 ( * scale -0.5) (* scale -1)))

(defvar my-mesh)
(setq my-mesh (make-mesh 'add (list part1 part2 part3)))

(duplicate 'rotation my-mesh 36 (vector 0 0 1) (vector 0 0 0) 10)
(duplicate 'homothety my-mesh 1 (vector 0 0 (* scale -10)) 1.05)


;(view 'mesh my-mesh)

(defvar hold1)
(setq hold1 (make-mesh 'restrict-point my-mesh (vector 1619)))
(defvar hold2)
(setq hold2 (make-mesh 'restrict-point my-mesh (vector 1625)))
(defvar hold)
(setq hold (make-mesh 'add (list hold1 hold2)))


;;;----------------------------------------------------------------------
;;; make objects
;;;----------------------------------------------------------------------

(defvar my-mesh-object)
(setq my-mesh-object
                (make-object 'finite-element
                (mesh my-mesh)
                (block hold)
                (modes 160)
                (density 9000)
                (young 1e11)
                (freq-loss 0.1)
                (const-loss 1)))

(compute-modes my-mesh-object)

;(save-object my-mesh-object "/Volumes/DataStor/_Vorlesungen_Seminare/physical_modeling/ex_lisp/gong_3d.txt")

;(view 'mode my-mesh-object 10 60 30)

(defvar my-hammer)
(setq my-hammer (make-object 'bi-two-mass))

;;;----------------------------------------------------------------------
;;; controller
;;;----------------------------------------------------------------------

(defvar hammer-ctrl)
(setq hammer-ctrl (make-controller 'dynamic 1 0 (list 0.1)))

;;;----------------------------------------------------------------------
;;; accesses
;;;----------------------------------------------------------------------

(defvar my-mesh-object-out1)
(setq my-mesh-object-out1 (make-access my-mesh-object (const 1357) 'normal))
(defvar my-mesh-object-out2)
(setq my-mesh-object-out2 (make-access my-mesh-object (const 1365) 'normal))

(defvar my-mesh-object-hit)
(setq my-mesh-object-hit (make-access my-mesh-object (const 965) 'normal)) ; dome 965 plateau 1350

(defvar my-hammer-tip)
(setq my-hammer-tip (make-access my-hammer (const 1) 'trans0))
(defvar my-hammer-top)
(setq my-hammer-top (make-access my-hammer (const 0) 'trans0))

;;;----------------------------------------------------------------------
;;; connections
;;;----------------------------------------------------------------------
                                       
(make-connection 'position my-hammer-top hammer-ctrl)

(make-connection 'strike my-hammer-tip .1 my-mesh-object-hit 0 (const 0.01))


;;;----------------------------------------------------------------------
;;; listening points
;;;----------------------------------------------------------------------

(make-point-output my-mesh-object-out1 0 (const 1))
(make-point-output my-mesh-object-out2 1 (const 1))

;;;----------------------------------------------------------------------
;;; run the synthesis and play the sound
;;;----------------------------------------------------------------------

(defvar list-dur)
(setq list-dur (list 1))
(defvar speed-coef)
(setq speed-coef .1)


(do ((i 0 (+ i 1))) ((= i (length list-dur)))

	(set-breakpoint hammer-ctrl (list 0.01 -0.001))
	(run 0.01)
	(set-breakpoint hammer-ctrl (list 0.01 0.1))
	(run (- (* (nth i list-dur) speed-coef) 0.01))
)

(run 10)
(play)

