
;;;----------------------------------------------------------------------
;;; Example 3h
;;; Hybride of two strings exited by a sound-file, a list is used to
;;; manage position in hybrid
;;;----------------------------------------------------------------------

(new)
(multi)
(set-sample-rate 44100)

(defun midi2hz (x) (* 440 (expt 2 (/ (- x 69) 12))))

;;;----------------------------------------------------------------------
;;; objects
;;;----------------------------------------------------------------------

(setq my-string1 
                (make-object 'bi-string
                                       (density 8000)
                                       (freq-loss 0.05)
                                       (const-loss 0.8)
				       (young 1.e11))) ;brass

(set-pitch my-string1 'tension (midi2hz 48))

(setq my-string2 
                (make-object 'bi-string
                                       (density 900)
                                       (freq-loss 5)
                                       (const-loss 5)
				       (young 2.e10))) ;pine

(set-pitch my-string2 'tension (midi2hz 48))

;;;----------------------------------------------------------------------
;;; controller
;;;----------------------------------------------------------------------

(setq input-controller (make-controller 'signal 1 (make-point-input 0 (const 1))))
                                      
;;;----------------------------------------------------------------------
;;; access
;;;----------------------------------------------------------------------

(setq my-string1-force (make-access my-string1 (const .1) 'trans0))
(setq my-string2-force (make-access my-string2 (const .1) 'trans0))

(setq my-string1-out (make-access my-string1 (const .9) 'trans0))
(setq my-string2-out (make-access my-string2 (const .9) 'trans0))
                                      
;;;----------------------------------------------------------------------
;;; hybrid
;;;----------------------------------------------------------------------

(setq my-hybrid (make-object 'melt-hybrid
                            my-string1 my-string2 (make-controller 'dynamic 1 -1 (list .0) "hybrid-pos")))

;;; access on hybrid

(setq my-hybrid-acc (make-access-hybrid my-hybrid my-string1-force my-string2-force))

;;; file/hybrid connection

(make-connection 'force my-hybrid-acc input-controller)

;;;----------------------------------------------------------------------
;;; listening point on hybrid 
;;;----------------------------------------------------------------------


(setq my-hybrid-out (make-access-hybrid my-hybrid my-string1-out my-string2-out))

(make-point-output my-hybrid-out 0 (const 1))

;;;----------------------------------------------------------------------
;;; run synthesis and save the script
;;;----------------------------------------------------------------------

(save-script "/Volumes/DataStor/_Vorlesungen_Seminare/physical_modeling/ex_max/03h-string-sound-hyb.mlys")